<?php
/*************************** APORIA WorksRegistration Class ***************************

	APORIA Works Registration
	Copyright © 2016, 2017 Gord Dimitrieff <gord@aporia-records.com>

	This file is part of APORIA Works Registration, a PHP library for reading, 
	writing and manipulating CISAC Common Works Registration (CWR) files.

	APORIA Works Registration is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	APORIA Works Registration is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with APORIA Works Registration.  If not, see <http://www.gnu.org/licenses/>.

*/
/*
	TIScsv2array.php
	This script generates PHP code from CISAC's TIS excel file (saved as a csv), which is then included by the WorksRegistration class.
	You only need to use this script if you need to regenerate the TIS-data.php file for any reason.

*/
ini_set('auto_detect_line_endings', TRUE);

function buildTree(array $elements, $parentId = 0) {
    $branch = array();

    foreach ($elements as $element) {
        if ($element['parent_id'] == $parentId) {
            $children = buildTree($elements, $element['TIS-N']);
            if ($children) {
                $element['children'] = $children;
            }
            $branch[] = $element;
        }
    }

    return $branch;
}

printf("Reading file...\n");

$rows = array_map('str_getcsv', file('TIS.csv'));
$header = array_shift($rows);
$csv = array();
foreach ($rows as $row) 
  $csv[] = array_combine($header, $row);

$position = 0;
$lastTIS = array();
$level = 1;

$TIS_List = array();

while($position < count($csv))
{
	$row =& $csv[$position];

	$previous_level = $level;
	$level = $row['Level'];
	$TIS = $row['TIS-N'];

	$row['Exists from'] = null;
	$row['Exists until'] = null;
	$row['Belongs to from'] = null;
	$row['Belongs to until'] = null;

	unset($row['Exists from']);
	unset($row['Exists until']);
	unset($row['Belongs to from']);
	unset($row['Belongs to until']);

	$row['Type'] = null;
	unset($row['Type']);
	$row['Level'] = null;
	unset($row['Level']);

	$TIS_List[$TIS] = $row['Name'];
	
	if($level == $previous_level && $level > 1)
	{
		$row['parent_id'] = $last_level_position[$level-1];
	}

	if($level > $previous_level && $level > 1) 
	{
		$row['parent_id'] = $last_level_position[$previous_level];
	}
	
	if($level < $previous_level)
	{
		$row['parent_id'] = $last_level_position[$level-1];
	}
	
	$last_level_position[$level] = $row['TIS-N'];

	$position++;
}

printf("Exporting CSV...\n");
$fp = fopen('TIS-keyed.csv', 'w');

fputcsv($fp, array_keys($row));
foreach ($csv as $row) {
    fputcsv($fp, $row);
}
fclose($fp);

printf("Building data tree...\n");
$tree = buildTree($csv);

printf("Writing php code...\n");
file_put_contents ("TIS-data.php" , "<?php\n/*\tThis file is an integral part of APORIA Works Registration, and was automatically generated by TIScsv2array.php\n\tVisit http://www.aporia-records.com/aws for more information.\n*/\n\$this->TISdata = ".var_export($tree, true).";\n?>" );

printf("Done.\n");

?>